@@ -4,14 +4,14 @@ use strict;
 use warnings;
 
 use Carp;
+use Config::Auto;
 use Config::IniFiles;
 use YAML::XS qw(LoadFile);
 use JSON::MaybeXS qw(decode_json);
 use XML::Simple qw(XMLin);
 use File::Slurp qw(read_file);
 use File::Spec;
-use File::Basename;
-use Hash::Merge qw( merge );
+use Hash::Merge qw(merge);
 use Hash::Flatten qw(flatten unflatten);
 use Params::Get;
 
@@ -21,11 +21,11 @@ Config::Abstraction - Configuration Abstraction Layer
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 SYNOPSIS
 
@@ -43,7 +43,7 @@ our $VERSION = '0.03';
 
 C<Config::Abstraction> is a flexible configuration management module
 that allows loading and merging configuration data from multiple file
-formats: YAML, JSON, XML, and INI.
+formats: YAML, JSON, XML, and INI via a number of different drivers.
 It also integrates environment variable
 overrides and command line arguments for runtime configuration adjustments.
 This module is designed to help developers manage layered configurations that can be loaded from files and overridden by environment variables,
@@ -202,11 +202,19 @@ A prefix for environment variable keys and comment line options, e.g. C<MYAPP_DA
 
 If true, returns a flat configuration structure like C<'database.user'> (default: C<0>).
 
+=item * C<sep_char>
+
+The separator in keys.
+The default is a C<'.'>,
+as in dotted notation,
+such as C<'database.user'>.
+
 =back
 
 =cut
 
-sub new {
+sub new
+{
 	my $class = shift;
 	my $params = Params::Get::get_params(undef, @_) || {};
 
@@ -216,6 +224,7 @@ sub new {
 		env_prefix => $params->{env_prefix} || 'APP_',
 		flatten	 => $params->{flatten} // 0,
 		config	=> {},
+		sep_char => '.'
 	}, $class;
 
 	$self->_load_config();
@@ -229,7 +238,7 @@ sub _load_config
 	my %merged;
 
 	for my $dir (@{ $self->{config_dirs} }) {
-		for my $file (qw/base.yaml base.json base.xml base.ini local.yaml local.json local.xml local.ini/) {
+		for my $file (qw/base.yaml base.yml base.json base.xml base.ini local.yaml local.yml local.json local.xml local.ini/) {
 			my $path = File::Spec->catfile($dir, $file);
 			next unless -f $path;
 
@@ -271,19 +280,22 @@ sub _load_config
 					}
 					if(!$data) {
 						$data = LoadFile($path);
-					}
-					if(!$data) {
-						if(my $ini = Config::IniFiles->new(-file => $path)) {
-							$data = { map {
-								my $section = $_;
-								$section => { map { $_ => $ini->val($section, $_) } $ini->Parameters($section) }
-							} $ini->Sections() };
+						if((!$data) || (ref($data) ne 'HASH')) {
+							if(my $ini = Config::IniFiles->new(-file => $path)) {
+								$data = { map {
+									my $section = $_;
+									$section => { map { $_ => $ini->val($section, $_) } $ini->Parameters($section) }
+								} $ini->Sections() };
+							}
+							if((!$data) || (ref($data) ne 'HASH')) {
+								# Maybe XML without the leading XML header
+								eval { $data = XMLin($path, ForceArray => 0, KeyAttr => []) };
+								if((!$data) || (ref($data) ne 'HASH')) {
+									$data = Config::Auto->new(source => $path)->parse();
+								}
+							}
 						}
 					}
-					if(!$data) {
-						# Maybe XML without the leading XML header
-						$data = XMLin($path, ForceArray => 0, KeyAttr => []);
-					}
 				};
 				if(scalar(keys %merged)) {
 					if($data) {
@@ -336,8 +348,8 @@ sub get
 	if($self->{flatten}) {
 		return $self->{config}{$key};
 	}
-	my $ref = $self->{config};
-	for my $part (split /\./, $key) {
+	my $ref = $self->{'config'};
+	for my $part (split qr/\Q$self->{sep_char}\E/, $key) {
 		return undef unless ref $ref eq 'HASH';
 		$ref = $ref->{$part};
 	}
@@ -360,6 +372,10 @@ sub all
 
 1;
 
+=head1 BUGS
+
+It should be possible to escape the separator character either with backslashes or quotes.
+
 =head1 SUPPORT
 
 This module is provided as-is without any warranty.
